@@ -1,2 +1,3 @@
 from pm4py.algo.conformance.alignments.versions import state_equation_a_star, dijkstra_no_heuristics, \
-    dijkstra_less_memory
+    dijkstra_less_memory, state_equation_less_memory
+
