@@ -7,7 +7,7 @@ CAUSAL_HEURISTIC = 'heuristic'
 VERSIONS = {CAUSAL_ALPHA: alpha.apply, CAUSAL_HEURISTIC: heuristic.apply}
 
 @deprecation.deprecated(deprecated_in='1.3.0', removed_in='2.0.0', current_version='',
-                        details='Use algorithm entrypoint instead')
+                        details='Use algorithm entrypoint instead (causal/factory)')
 def apply(dfg, variant=CAUSAL_ALPHA):
     """
     Computes the causal relation on the basis of a given directly follows graph.
