@@ -36,3 +36,25 @@ def apply(log, variant=DEFAULT_VARIANT, parameters=None):
         Log skeleton model
     """
     return exec_utils.get_variant(variant).apply(log_conversion.apply(log, parameters=parameters), parameters=parameters)
+
+
+def apply_from_variants_list(var_list, variant=DEFAULT_VARIANT, parameters=None):
+    """
+    Discovers the log skeleton from the variants list
+
+    Parameters
+    ---------------
+    var_list
+        Variants list
+    variant
+        Variant of the algorithm, possible values:
+        - Variants.CLASSIC
+    parameters
+        Parameters
+
+    Returns
+    -------------
+    model
+        Log skeleton model
+    """
+    return exec_utils.get_variant(variant).apply_from_variants_list(var_list, parameters=parameters)
