@@ -1,2 +1,2 @@
 from pm4py.algo.filtering.pandas import start_activities, end_activities, attributes, cases, \
-    pd_filtering_constants, variants, paths, timestamp
+    pd_filtering_constants, variants, paths, timestamp, ltl
