@@ -1,2 +1,2 @@
 from pm4py.objects import log, petri, transition_system, conversion, process_tree, heuristics_net, random_variables, \
-    stochastic_petri
+    stochastic_petri, dfg
