@@ -9,7 +9,7 @@ VERSIONS = {TO_PETRI_NET: to_petri_net.apply, TO_PETRI_NET_TRANSITION_BORDERED:
 
 
 @deprecation.deprecated(deprecated_in='1.3.0', removed_in='2.0.0', current_version='',
-                        details='Use algorithm entrypoint instead')
+                        details='Use algorithm entrypoint instead (conversion/process_tree/factory)')
 def apply(tree, parameters=None, variant=TO_PETRI_NET):
     """
     Method for converting from Process Tree to Petri net
