@@ -7,9 +7,10 @@ from lxml import etree, objectify
 from pm4py.objects import petri
 from pm4py.objects.petri.common import final_marking
 from pm4py.objects.random_variables.random_variable import RandomVariable
+from pm4py.util import constants
 
 
-def import_petri_from_string(petri_string, return_stochastic_information=False, parameters=None):
+def import_petri_from_string(petri_string, parameters=None):
     """
     Import a Petri net from a string
 
@@ -17,8 +18,6 @@ def import_petri_from_string(petri_string, return_stochastic_information=False,
     ----------
     petri_string
         Petri net expressed as PNML string
-    return_stochastic_information
-        Enables return of stochastic information if found in the PNML
     parameters
         Other parameters of the algorithm
     """
@@ -29,13 +28,12 @@ def import_petri_from_string(petri_string, return_stochastic_information=False,
     fp.close()
     with open(fp.name, 'w') as f:
         f.write(petri_string)
-    net, initial_marking, this_final_marking = import_net(fp.name,
-                                                          return_stochastic_information=return_stochastic_information)
+    net, initial_marking, this_final_marking = import_net(fp.name)
     os.remove(fp.name)
     return net, initial_marking, this_final_marking
 
 
-def import_net(input_file_path, return_stochastic_information=False, parameters=None):
+def import_net(input_file_path, parameters=None):
     """
     Import a Petri net from a PNML file
 
@@ -43,8 +41,6 @@ def import_net(input_file_path, return_stochastic_information=False, parameters=
     ----------
     input_file_path
         Input file path
-    return_stochastic_information
-        Enables return of stochastic information if found in the PNML
     parameters
         Other parameters of the algorithm
     """
@@ -84,27 +80,46 @@ def import_net(input_file_path, return_stochastic_information=False, parameters=
     if page is not None:
         for child in page:
             if "place" in child.tag:
+                position_X = None
+                position_Y = None
+                dimension_X = None
+                dimension_Y = None
                 place_id = child.get("id")
                 place_name = place_id
                 number = 0
                 for child2 in child:
-                    if "name" in child2.tag:
+                    if child2.tag.endswith('name'):
                         for child3 in child2:
                             if child3.text:
                                 place_name = child3.text
-                    if "initialMarking" in child2.tag:
+                    if child2.tag.endswith('initialMarking'):
                         for child3 in child2:
-                            if child3.tag == "text":
+                            if child3.tag.endswith("text"):
                                 number = int(child3.text)
+                    if child2.tag.endswith('graphics'):
+                        for child3 in child2:
+                            if child3.tag.endswith('position'):
+                                position_X = float(child3.get("x"))
+                                position_Y = float(child3.get("y"))
+                            elif child3.tag.endswith("dimension"):
+                                dimension_X = float(child3.get("x"))
+                                dimension_Y = float(child3.get("y"))
                 places_dict[place_id] = petri.petrinet.PetriNet.Place(place_id)
+                places_dict[place_id].properties[constants.PLACE_NAME_TAG] = place_name
                 net.places.add(places_dict[place_id])
+                if position_X is not None and position_Y is not None and dimension_X is not None and dimension_Y is not None:
+                    places_dict[place_id].properties[constants.LAYOUT_INFORMATION_PETRI] = ((position_X, position_Y), (dimension_X, dimension_Y))
                 if number > 0:
                     marking[places_dict[place_id]] = number
                 del place_name
 
     if page is not None:
         for child in page:
-            if "transition" in child.tag:
+            if child.tag.endswith("transition"):
+                position_X = None
+                position_Y = None
+                dimension_X = None
+                dimension_Y = None
                 trans_name = child.get("id")
                 trans_label = trans_name
                 trans_visible = True
@@ -112,12 +127,20 @@ def import_net(input_file_path, return_stochastic_information=False, parameters=
                 random_variable = None
 
                 for child2 in child:
-                    if child2.tag == "name":
+                    if child2.tag.endswith("name"):
                         for child3 in child2:
                             if child3.text:
                                 if trans_label == trans_name:
                                     trans_label = child3.text
-                    if "toolspecific" in child2.tag:
+                    if child2.tag.endswith("graphics"):
+                        for child3 in child2:
+                            if child3.tag.endswith("position"):
+                                position_X = float(child3.get("x"))
+                                position_Y = float(child3.get("y"))
+                            elif child3.tag.endswith("dimension"):
+                                dimension_X = float(child3.get("x"))
+                                dimension_Y = float(child3.get("y"))
+                    if child2.tag.endswith("toolspecific"):
                         tool = child2.get("tool")
                         if "ProM" in tool:
                             activity = child2.get("activity")
@@ -142,11 +165,11 @@ def import_net(input_file_path, return_stochastic_information=False, parameters=
                                 elif key == "weight":
                                     weight = float(value)
 
-                            if return_stochastic_information:
-                                random_variable = RandomVariable()
-                                random_variable.read_from_string(distribution_type, distribution_parameters)
-                                random_variable.set_priority(priority)
-                                random_variable.set_weight(weight)
+                            random_variable = RandomVariable()
+                            random_variable.read_from_string(distribution_type, distribution_parameters)
+                            random_variable.set_priority(priority)
+                            random_variable.set_weight(weight)
+
                 if not trans_visible:
                     trans_label = None
                 #if "INVISIBLE" in trans_label:
@@ -156,19 +179,21 @@ def import_net(input_file_path, return_stochastic_information=False, parameters=
                 net.transitions.add(trans_dict[trans_name])
 
                 if random_variable is not None:
-                    stochastic_information[trans_dict[trans_name]] = random_variable
+                    trans_dict[trans_name].properties[constants.STOCHASTIC_DISTRIBUTION] = random_variable
+                if position_X is not None and position_Y is not None and dimension_X is not None and dimension_Y is not None:
+                    trans_dict[trans_name].properties[constants.LAYOUT_INFORMATION_PETRI] = ((position_X, position_Y), (dimension_X, dimension_Y))
 
     if page is not None:
         for child in page:
-            if "arc" in child.tag:
+            if child.tag.endswith("arc"):
                 arc_source = child.get("source")
                 arc_target = child.get("target")
                 arc_weight = 1
 
                 for arc_child in child:
-                    if "inscription" in arc_child.tag:
+                    if arc_child.tag.endswith("inscription"):
                         for text_arcweight in arc_child:
-                            if "text" in text_arcweight.tag:
+                            if text_arcweight.tag.endswith("text"):
                                 arc_weight = int(text_arcweight.text)
 
                 if arc_source in places_dict and arc_target in trans_dict:
@@ -181,7 +206,7 @@ def import_net(input_file_path, return_stochastic_information=False, parameters=
             for child2 in child:
                 place_id = child2.get("idref")
                 for child3 in child2:
-                    if "text" in child3.tag:
+                    if child3.tag.endswith("text"):
                         number = int(child3.text)
                         if number > 0:
                             fmarking[places_dict[place_id]] = number
@@ -190,7 +215,4 @@ def import_net(input_file_path, return_stochastic_information=False, parameters=
     if len(fmarking) == 0:
         fmarking = final_marking.discover_final_marking(net)
 
-    if return_stochastic_information and len(list(stochastic_information.keys())) > 0:
-        return net, marking, fmarking, stochastic_information
-
-    return net, marking, fmarking
\ No newline at end of file
+    return net, marking, fmarking
