@@ -12,7 +12,7 @@ DEFAULT_SAMPLE_SIZE = 10000
 VERSIONS = {DATAFRAME: dataframe.apply, LOG: log.apply}
 
 @deprecation.deprecated(deprecated_in='1.3.0', removed_in='2.0.0', current_version='',
-                        details='Use algorithm entrypoint instead')
+                        details='Use algorithm entrypoint instead (performance_spectrum/factory)')
 def apply(log, list_activities, parameters=None):
     """
     Finds the performance spectrum provided a log/dataframe
